@@ -10,7 +10,7 @@ morphoMockup = .morphodataFromDataFrame(morphoDataFrame)
 # locally suppress warnings
 data(centaurea)
 centaurea = suppressWarnings(naMeanSubst(centaurea))
-centaurea = deletePopulation(centaurea, populationName = c("LIP", "PREL"))
+centaurea = removePopulation(centaurea, populationName = c("LIP", "PREL"))
 
 pops=populOTU(centaurea)
 
